import { useNavigate } from 'react-router-dom'
import { getProfileRoute } from '../../routes'

import styles from './styles.module.scss'
import React from 'react'
import { AvatarIconButton } from '../UserAvatarIconButton'

interface UserAvatarProps {
  name: string
  pubkey: string
  image?: string
}

/**
 *  This component will be used for the displaying username and profile picture.
 *  Clicking will navigate to the user's profile.
 */
export const UserAvatar = ({ pubkey, name, image }: UserAvatarProps) => {
  const navigate = useNavigate()

  const handleClick = (e: React.MouseEvent<HTMLElement, MouseEvent>) => {
    e.stopPropagation()
    navigate(getProfileRoute(pubkey))
  }

  return (
    <div className={styles.container}>
      <AvatarIconButton
        src={image}
        hexKey={pubkey}
        aria-label={`account of user ${name}`}
        color="inherit"
        onClick={handleClick}
      />
      {name ? (
        <label onClick={handleClick} className={styles.username}>
          {name}
        </label>
      ) : null}
    </div>
  )
}
